complete_model_info: Complete model diagnostics from learner predictions when the...

View source: R/helper_vimpute.R

complete_model_infoR Documentation

Complete model diagnostics from learner predictions when the raw model does not expose them directly

Description

Complete model diagnostics from learner predictions when the raw model does not expose them directly

Usage

complete_model_info(info, learner = NULL, task = NULL)

Arguments

info

Result from extract_model_info()

learner

A trained mlr3 learner or GraphLearner

task

A regression task used for training the learner

Value

Model info list with residuals/scale filled where possible


VIM documentation built on Sept. 2, 2026, 5:07 p.m.