countInf: Count number of infinite or missing values

View source: R/utils.R

countInfR Documentation

Count number of infinite or missing values

Description

Count the number of infinite or missing values in a vector.

Usage

countInf(x)

Arguments

x

a vector.

Value

countInf returns the number of infinite values in x. countNA returns the number of missing values in x.

Author(s)

Andreas Alfons

Examples

data(sleep, package="VIM")
countInf(log(sleep$Dream))
countNA(sleep$Dream)

VIM documentation built on Sept. 2, 2026, 5:07 p.m.