Multiple imputation using classical and robust methods accounting for model and imputation uncertainty.
imputeRobust(
form,
data,
boot = TRUE,
robustboot = "stratified",
method = "MM",
takeAll = TRUE,
alpha = 0.75,
uncert = "pmm",
family = "Gaussian",
value_back = "all"
)Model formulas as a list.
Data set to impute
Accounting for model uncertainty with a classical bootstrap, Default: TRUE
Accounting for model uncertainty with robust bootstrap methods, Default: 'stratified'
Imputation method, Default: 'MM'
Missing values are intialized when TRUE, Default: TRUE
Relative size of good data points. Used for the robust bootstrap methods, Default: 0.75
Imputation uncertainty method, Default: 'pmm'
Not supported and ignored. Foreseen for future versions, Default: 'Gaussian'
Only observations with imputed values as return object (ymiss), or the whole data set, Default: 'all'
Imputed data set.
Complex formulas can be provided for each variable in your data set.
Other imputation methods:
hotdeck(),
impPCA(),
imputeRobustChain(),
irmi(),
kNN(),
matchImpute(),
medianSamp(),
rangerImpute(),
regressionImp(),
sampleCat(),
vimpute(),
xgboostImpute()
if (FALSE) { # \dontrun{
if(interactive()){
#EXAMPLE1
}
} # }