Learn R Programming

VIM (version 7.3.0)

sampleCat: Random aggregation function for a factor variable

Description

The function sampleCat samples with probabilites corresponding to the occurrence of the level in the NNs.

Usage

sampleCat(x, weights = NULL)

Arguments

x

factor vector

weights

numeric vector providing weights for the observations in x

See Also

Other imputation methods: hotdeck(), impPCA(), imputeCellEM(), imputeCellIRMI(), imputeCellM(), imputeCellMCD(), imputeCellwise(), imputeRobust(), imputeRobustChain(), irmi(), kNN(), matchImpute(), medianSamp(), rangerImpute(), regressionImp(), vimmi, vimpute(), xgboostImpute()