View source: R/helper_vimpute.R
| bootstrap_resample | R Documentation |
Returns bootstrap row indices based on the chosen strategy. Strategies adapted from imputeRobust (Templ 2024).
bootstrap_resample(
n,
strategy = "stratified",
weights = NULL,
residuals = NULL,
alpha = 0.75,
best_subset = NULL
)
n |
Number of observations |
strategy |
One of "standard", "stratified", "residual" |
weights |
Robustness weights from model (currently unused in active strategies). |
residuals |
Model residuals. Used by "stratified" and "residual". |
alpha |
Fraction of "good" observations (default 0.75). Used by "stratified". |
best_subset |
Integer indices of best observations (currently unused). |
Integer vector of length n with bootstrap row indices
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.