View source: R/cellwise_utils.R
| cellWeightsFromResiduals | R Documentation |
Given a vector of residuals and a robust scale estimate, standardize and apply a robust weight function. This is used inside the IRWLS loop to compute psi-weights from the current fit residuals.
cellWeightsFromResiduals(residuals, sigma, method = "huber", alpha = NULL)
residuals |
numeric n-vector of residuals from the current fit |
sigma |
robust scale estimate (e.g. MAD of residuals). If zero or very small, all weights are set to 1. |
method |
weight function: |
alpha |
tuning constant. If |
numeric n-vector of weights in [0, 1]
Matthias Templ
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.