View source: R/helper_vimpute.R
| complete_model_info | R Documentation |
Complete model diagnostics from learner predictions when the raw model does not expose them directly
complete_model_info(info, learner = NULL, task = NULL)
info |
Result from extract_model_info() |
learner |
A trained mlr3 learner or GraphLearner |
task |
A regression task used for training the learner |
Model info list with residuals/scale filled where possible
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.