Convenience wrapper that dispatches to one of the three cellwise-robust imputation methods: imputeCellIRMI, imputeCellM, or imputeCellEM.

imputeCellwise(data, method = c("cellIRMI", "cellM", "cellEM"), ...)

Arguments

data

data.frame with missing values (mixed continuous + categorical).

method

imputation method: "cellIRMI" (default), "cellM", or "cellEM".

...

additional arguments passed to the chosen method.

Value

The return value of the dispatched function. See the documentation of the individual methods for details.

Note

Model uncertainty via bootstrap (Rubin's combining rules for multiple imputation) is not yet implemented. The current version provides single imputation with stochastic uncertainty (PMM or residual draw). For valid multiple imputation, call the function repeatedly with different seeds and combine using Rubin's rules.

Author

Matthias Templ

Examples

# \donttest{
data(sleep, package = "VIM")
result <- imputeCellwise(sleep, method = "cellIRMI")
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in coefficient 'Overall'.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S refinements did not converge (to refine.tol=1e-07) in 200 (= k.max) steps
#> Warning: S refinements did not converge (to refine.tol=1e-07) in 200 (= k.max) steps
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S refinements did not converge (to refine.tol=1e-07) in 200 (= k.max) steps
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in coefficient 'Overall'.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in coefficient 'Overall'.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in coefficient 'Overall'.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: find_scale() did not converge in 'maxit.scale' (= 200) iterations with tol=1e-10, last rel.diff=0
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in coefficient 'Overall'.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: Detected possible local breakdown of S-estimate in 2 coefficients 'Overall', ''.
#> Use lmrob argument 'setting="KS2014"' to avoid this problem.
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
#> Warning: S-estimated scale == 0:  Probably exact fit; check your data
head(result$data_imputed)
#>   BodyWgt BrainWgt NonD Dream Sleep Span Gest Pred Exp Danger
#> 1  55.500    157.0 10.0   0.5   2.9 20.0  645    4   1      3
#> 2   1.000      6.6  6.3   2.0   8.3  4.5   42    3   1      3
#> 3   3.385     44.5 15.8   2.8  13.3 14.0   60    1   1      1
#> 4   0.920     11.4 15.2   0.9  17.0 27.0  115    2   2      3
#> 5  14.830    115.0  2.1   0.5   2.9 20.0   33    5   5      4
#> 6  10.550    179.5  9.1   0.7   9.8 27.0  180    4   4      4
# }