Learn R Programming

VIM (version 7.3.0)

imputeCellwise: Unified cellwise-robust imputation dispatcher

Description

Convenience wrapper that dispatches to one of the three cellwise-robust imputation methods: imputeCellIRMI, imputeCellM, or imputeCellEM.

Usage

imputeCellwise(data, method = c("cellIRMI", "cellM", "cellEM"), ...)

Value

The return value of the dispatched function. See the documentation of the individual methods for details.

Arguments

data

data.frame with missing values (mixed continuous + categorical).

method

imputation method: "cellIRMI" (default), "cellM", or "cellEM".

...

additional arguments passed to the chosen method.

Author

Matthias Templ

See Also

imputeCellIRMI, imputeCellM, imputeCellEM

Other imputation methods: hotdeck(), impPCA(), imputeCellEM(), imputeCellIRMI(), imputeCellM(), imputeCellMCD(), imputeRobust(), imputeRobustChain(), irmi(), kNN(), matchImpute(), medianSamp(), rangerImpute(), regressionImp(), sampleCat(), vimmi, vimpute(), xgboostImpute()

Examples

Run this code
# \donttest{
data(sleep, package = "VIM")
result <- imputeCellwise(sleep, method = "cellIRMI")
head(result$data_imputed)
# }

Run the code above in your browser using DataLab