powered by
Convenience wrapper that dispatches to one of the three cellwise-robust imputation methods: imputeCellIRMI, imputeCellM, or imputeCellEM.
imputeCellIRMI
imputeCellM
imputeCellEM
imputeCellwise(data, method = c("cellIRMI", "cellM", "cellEM"), ...)
The return value of the dispatched function. See the documentation of the individual methods for details.
data.frame with missing values (mixed continuous + categorical).
imputation method: "cellIRMI" (default), "cellM", or "cellEM".
"cellIRMI"
"cellM"
"cellEM"
additional arguments passed to the chosen method.
Matthias Templ
imputeCellIRMI, imputeCellM, imputeCellEM
Other imputation methods: hotdeck(), impPCA(), imputeCellEM(), imputeCellIRMI(), imputeCellM(), imputeCellMCD(), imputeRobust(), imputeRobustChain(), irmi(), kNN(), matchImpute(), medianSamp(), rangerImpute(), regressionImp(), sampleCat(), vimmi, vimpute(), xgboostImpute()
hotdeck()
impPCA()
imputeCellEM()
imputeCellIRMI()
imputeCellM()
imputeCellMCD()
imputeRobust()
imputeRobustChain()
irmi()
kNN()
matchImpute()
medianSamp()
rangerImpute()
regressionImp()
sampleCat()
vimmi
vimpute()
xgboostImpute()
# \donttest{ data(sleep, package = "VIM") result <- imputeCellwise(sleep, method = "cellIRMI") head(result$data_imputed) # }
Run the code above in your browser using DataLab