Learn R Programming

VIM (version 7.3.0)

medianSamp: Aggregation function for a ordinal variable

Description

The function medianSamp chooses the level as the median or randomly between two levels.

Usage

medianSamp(x, weights = NULL)

Arguments

x

ordered factor vector

weights

numeric vector providing weights for the observations in x

See Also

Other imputation methods: hotdeck(), impPCA(), imputeCellEM(), imputeCellIRMI(), imputeCellM(), imputeCellMCD(), imputeCellwise(), imputeRobust(), imputeRobustChain(), irmi(), kNN(), matchImpute(), rangerImpute(), regressionImp(), sampleCat(), vimmi, vimpute(), xgboostImpute()