medianSamp: Aggregation function for a ordinal variable
Description
The function medianSamp chooses the level as the median or randomly between
two levels.
Usage
medianSamp(x, weights = NULL)
Arguments
- x
ordered factor vector
- weights
numeric vector providing weights for the observations in x