View source: R/helper_vimpute.R
| pmm_observed_scores | R Documentation |
Scores the observed rows of a target with the trained learner so that PMM donors are matched on their predicted values (Little 1988), not on their observed values. For a ranger fit without bootstrap resampling the honest out-of-bag predictions are used; otherwise the trained learner predicts the observed rows (aregImpute-style when the fit is a bootstrap refit). Returns NULL when the rows cannot be scored.
pmm_observed_scores(
learner,
data_temp,
obs_idx,
feature_cols,
target_col,
factor_levels,
method_var,
boot,
lhs_transformation = NULL
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.