Learn R Programming

VIM (version 7.3.0)

rangerImpute: Random Forest Imputation

Description

Impute missing values based on random-forest models via vimpute().

Usage

rangerImpute(
  formula,
  data,
  imp_var = TRUE,
  imp_suffix = "imp",
  ...,
  verbose = FALSE,
  median = FALSE
)

Value

the imputed data set.

Arguments

formula

model formula for the imputation

data

A data.frame containing the data

imp_var

TRUE/FALSE if a TRUE/FALSE variables for each imputed variable should be created show the imputation status

imp_suffix

suffix used for TF imputation variables

...

Additional ranger hyperparameters (e.g. num.trees, mtry, min.node.size), forwarded to the ranger learner via vimpute().

verbose

Show the number of observations used for training and evaluating the RF-Model.

median

TRUE/FALSE. If TRUE, ranger regression predictions are aggregated tree-wise using the median (via vimpute()).

See Also

Other imputation methods: hotdeck(), impPCA(), imputeCellEM(), imputeCellIRMI(), imputeCellM(), imputeCellMCD(), imputeCellwise(), imputeRobust(), imputeRobustChain(), irmi(), kNN(), matchImpute(), medianSamp(), regressionImp(), sampleCat(), vimmi, vimpute(), xgboostImpute()

Examples

Run this code
data(sleep)
rangerImpute(Dream+NonD~BodyWgt+BrainWgt,data=sleep)

Run the code above in your browser using DataLab